@@ -6,21 +6,22 @@ squarecrop.py
 Created by FI$H 2000 on 2012-08-23.
 Copyright (c) 2012 Objects In Space And Time, LLC. All rights reserved.
 """
+from __future__ import print_function
 
-def histogram_entropy(im):
+def histogram_entropy(image):
     """ Calculate the entropy of an images' histogram.
         Used for "smart cropping" in easy-thumbnails:
             https://raw.github.com/SmileyChris/easy-thumbnails/master/easy_thumbnails/utils.py
     """
     import math
-
-    if not hasattr(im, 'histogram'):
+    
+    if not hasattr(image, 'histogram'):
         return 0  # Fall back to a constant entropy.
-
-    histogram = im.histogram()
-    hist_ceil = float(sum(histogram))
-    histonorm = [histocol / hist_ceil for histocol in histogram]
-
+    
+    histogram = image.histogram()
+    histosum = float(sum(histogram))
+    histonorm = [histocol / histosum for histocol in histogram]
+    
     return -sum([p * math.log(p, 2) for p in histonorm if p != 0])
 
 def compare_entropy(start_slice, end_slice, slice, difference):
@@ -38,7 +39,7 @@ def compare_entropy(start_slice, end_slice, slice, difference):
             return slice, slice
         half_slice = slice // 2
         return half_slice, slice - half_slice
-
+    
     if start_entropy > end_entropy:
         return 0, slice
     else:
@@ -48,56 +49,56 @@ class SquareCrop(object):
     """ Crop an image to an Instagrammy square,
         by whittling away the parts of the image
         with the least entropy.
-
+        
         Based on smart crop implementation from easy-thumbnails:
             https://github.com/SmileyChris/easy-thumbnails/blob/master/easy_thumbnails/processors.py#L193
     """
-
-    def process(self, img):
-        source_x, source_y = img.size
-        target_width = target_height = min(img.size)
+    
+    def process(self, image):
+        source_x, source_y = image.size
+        target_width = target_height = min(image.size)
         
         diff_x = int(source_x - min(source_x, target_width))
         diff_y = int(source_y - min(source_y, target_height))
         left = top = 0
         right, bottom = source_x, source_y
-
+        
         while diff_x:
             slice = min(diff_x, max(diff_x // 5, 10))
-            start = img.crop((left, 0, left + slice, source_y))
-            end = img.crop((right - slice, 0, right, source_y))
+            start = image.crop((left, 0, left + slice, source_y))
+            end = image.crop((right - slice, 0, right, source_y))
             add, remove = compare_entropy(start, end, slice, diff_x)
             left += add
             right -= remove
             diff_x = diff_x - add - remove
-
+        
         while diff_y:
             slice = min(diff_y, max(diff_y // 5, 10))
-            start = img.crop((0, top, source_x, top + slice))
-            end = img.crop((0, bottom - slice, source_x, bottom))
+            start = image.crop((0, top, source_x, top + slice))
+            end = image.crop((0, bottom - slice, source_x, bottom))
             add, remove = compare_entropy(start, end, slice, diff_y)
             top += add
             bottom -= remove
             diff_y = diff_y - add - remove
-
+        
         box = (left, top, right, bottom)
-        return img.crop(box)
+        return image.crop(box)
 
 
 if __name__ == '__main__':
     from PIL import Image
     from instakit.utils import static
     
-    image_paths = map(
+    image_paths = list(map(
         lambda image_file: static.path('img', image_file),
-            static.listfiles('img'))
-    image_inputs = map(
+            static.listfiles('img')))
+    image_inputs = list(map(
         lambda image_path: Image.open(image_path).convert('RGB'),
-            image_paths)
+            image_paths))
     
     for image_input in image_inputs:
         image_input.show()
         SquareCrop().process(image_input).show()
     
-    print image_paths
+    print(image_paths)
     
